? DVD ? config.sh ? log.txt ? mythtvburn.lck ? temp ? mythwebburn/config.php Index: createbackgroundthumbs.sh =================================================================== RCS file: /cvsroot/mythburn/mythburn/createbackgroundthumbs.sh,v retrieving revision 1.2 diff -u -B -b -r1.2 createbackgroundthumbs.sh --- createbackgroundthumbs.sh 3 Oct 2004 18:27:08 -0000 1.2 +++ createbackgroundthumbs.sh 19 Mar 2005 13:35:10 -0000 @@ -1,5 +1,7 @@ #!/bin/sh +source config.sh + rm -f $1/images/backgrounds/thumbnails/*.png cd $1/images/backgrounds @@ -10,5 +12,5 @@ convert -size 140x105 "$file" -resize 140x105 "$1/images/backgrounds/thumbnails/$file" done -chown -R mythtv:www-data $1/images/backgrounds/thumbnails/* +chown -R $mythtvuser:$mythwebgroup $1/images/backgrounds/thumbnails/* \ No newline at end of file Index: install.sh =================================================================== RCS file: /cvsroot/mythburn/mythburn/install.sh,v retrieving revision 1.7 diff -u -B -b -r1.7 install.sh --- install.sh 3 Mar 2005 18:09:55 -0000 1.7 +++ install.sh 19 Mar 2005 13:35:10 -0000 @@ -2,6 +2,8 @@ # Written By spit2k1 # Updated 06 Sept 2004 +source config.sh + # Change this folder to point to where this script is running from # or just let it choose the current folder myfolder=`pwd` @@ -11,78 +13,79 @@ mythtv=/myth/tv #Automatically locate the mythtvosd file - use first one found under /usr folder -mythtvosd=$(which mythtvosd) +mythtvosd=`which mythtvosd` avidemux2=`which avidemux2` - +tcdemux=`which tcdemux` +transcode=`which transcode` echo install.sh is running in $myfolder"" -#Some very over the top code to replace hardcoded paths in various scripts dynamically. -#ToDo: must improve on the way this is done! +cp $myfolder""/config.sh $myfolder""/config.bak +sed -e "s!^myfolder=.*!myfolder=$myfolder""!;" $myfolder""/config.bak > $myfolder""/config.sh -cp $myfolder""/mythtvburn.sh $myfolder""/mythtvburn.bak -sed -e "s!^myfolder=.*!myfolder=$myfolder""!;" $myfolder""/mythtvburn.bak > $myfolder""/mythtvburn.sh +cp $myfolder""/config.sh $myfolder""/config.bak +sed -e "s!^mythtvlocation=.*!mythtvlocation=$mythtv""!;" $myfolder""/config.bak > $myfolder""/config.sh -cp $myfolder""/mythtvburn.sh $myfolder""/mythtvburn.bak -sed -e "s!^mythtvlocation=.*!mythtvlocation=$mythtv""!;" $myfolder""/mythtvburn.bak > $myfolder""/mythtvburn.sh +cp $myfolder""/config.sh $myfolder""/config.bak +sed -e "s!^mythtvosd=.*!mythtvosd=$mythtvosd""!;" $myfolder""/config.bak > $myfolder""/config.sh -cp $myfolder""/mythtvburn.sh $myfolder""/mythtvburn.bak -sed -e "s!^mythtvosd=.*!mythtvosd=$mythtvosd""!;" $myfolder""/mythtvburn.bak > $myfolder""/mythtvburn.sh +cp $myfolder""/config.sh $myfolder""/config.bak +sed -e "s!^avidemux2=.*!avidemux2=$avidemux2""!;" $myfolder""/config.bak > $myfolder""/config.sh -#Same for PHP files... -cp $myfolder""/mythwebburn/mythtvburndvd_createdvd.php $myfolder""/mythwebburn/mythtvburndvd_createdvd.bak -sed -e "s!^\$mythburnfolder=.*!\$mythburnfolder='$myfolder""';!;" $myfolder""/mythwebburn/mythtvburndvd_createdvd.bak > $myfolder""/mythwebburn/mythtvburndvd_createdvd.php +cp $myfolder""/config.sh $myfolder""/config.bak +sed -e "s!^tcdemux=.*!tcdemux=$tcdemux""!;" $myfolder""/config.bak > $myfolder""/config.sh -cp $myfolder""/mythwebburn/mythtvburndvd.php $myfolder""/mythwebburn/mythtvburndvd.bak -sed -e "s!^\$mythburnfolder=.*!\$mythburnfolder='$myfolder""';!;" $myfolder""/mythwebburn/mythtvburndvd.bak > $myfolder""/mythwebburn/mythtvburndvd.php +cp $myfolder""/config.sh $myfolder""/config.bak +sed -e "s!^transcode=.*!transcode=$transcode""!;" $myfolder""/config.bak > $myfolder""/config.sh + +cp $myfolder""/mythtvburn.sh $myfolder""/mythtvburn.bak +sed -e "s!^source .*!source $myfolder/config.sh # location of config file""!;" $myfolder""/mythtvburn.bak > $myfolder""/mythtvburn.sh -cp $myfolder""/mythwebburn/mythtvburndvd_confirm.php $myfolder""/mythwebburn/mythtvburndvd_confirm.bak -sed -e "s!^\$mythrecordings=.*!\$mythrecordings='$mythtv""';!;" $myfolder""/mythwebburn/mythtvburndvd_confirm.bak > $myfolder""/mythwebburn/mythtvburndvd_confirm.php +cp $myfolder""/scripts/getmyth.sh $myfolder""/scripts/getmyth.bak +sed -e "s!^source .*!source $myfolder/config.sh # location of config file""!;" $myfolder""/scripts/getmyth.bak > $myfolder""/scripts/getmyth.sh +cp $myfolder""/scripts/extractthumbnail.sh $myfolder""/scripts/extractthumbnail.bak +sed -e "s!^source .*!source $myfolder/config.sh # location of config file""!;" $myfolder""/scripts/extractthumbnail.bak > $myfolder""/scripts/extractthumbnail.sh + +rm -f $myfolder""/config.bak rm -f $myfolder""/mythtvburn.bak +rm -f $myfolder""/scripts/getmyth.bak +rm -f $myfolder""/scripts/extractthumbnail.bak +exit +#Same for PHP files... +cp $myfolder""/mythwebburn/config.php $myfolder""/mythwebburn/config.bak +sed -e "s!^\$mythburnfolder=.*!\$mythburnfolder='$myfolder""';!;" $myfolder""/mythwebburn/config.bak > $myfolder""/mythwebburn/config.php +cp $myfolder""/mythwebburn/config.php $myfolder""/mythwebburn/config.bak +sed -e "s!^\$mythrecordings=.*!\$mythrecordings='$mythtv""';!;" $myfolder""/mythwebburn/config.bak > $myfolder""/mythwebburn/config.php + +rm -f $myfolder""/mythwebburn/config.bak echo "Dependancy version checks....." -dpkg -s mjpegtools | grep "Version:" +echo "" +echo "" + +mplex -h 2>&1 | grep -m1 " version " echo "Must be at least version 1:1.6.2-0.6" echo "" echo "" -dpkg -s dvdauthor | grep "Version:" +dvdauthor -h 2>&1 | grep -m1 " version " echo "Must be at least version 0.6.10-4" echo "" echo "" -dpkg -s imagemagick | grep "Version:" +convert -version 2>&1 | grep -m1 "Version: " echo "Must be at least version 6:6.0.6.2-1.5" echo "" echo "" -dpkg -s xvfb | grep "Version:" +X -version 2>&1 | grep -m1 "Version" echo "Must be at least version 4.3.0.dfsg.1-8" echo "" echo "" - - -echo mythtvosd is located at $mythtvosd - -echo "Currently MythTV Burn is set to run from folder" -grep myfolder= mythtvburn.sh - -echo "Currently MythTV Burn is set to use MythTV recordings from folder" -grep mythtvlocation= mythtvburn.sh - -echo "You must edit mythtvburn.sh and change these values if this is not correct" - -echo "" -echo "" -echo "" -echo "" -echo "Creating 5 sample background menu images" - - #Does not really matter about size of images, they are resized later pageresolution=720x576 @@ -109,11 +112,8 @@ echo Creating thumbnail of background images $myfolder""/createbackgroundthumbs.sh $myfolder"" -echo "Installing MythTV web burn interface" -# Backup original theme file - -mythwebfolder=/var/www +echo "Installing MythTV web burn interface" # Check if MythWeb is installed to /var/www or /var/www/mythweb if [ -e "$mythwebfolder""/mythweb/program_listing.php" ]; then @@ -134,19 +134,19 @@ fi mkdir $myfolder""/temp -chown www-data:www-data $myfolder""/temp +chown $mythwebuser:$mythwebgroup $myfolder""/temp # Create DVD and temp folders rm -dfr $myfolder""/DVD mkdir $myfolder""/DVD -chown www-data:www-data $myfolder""/DVD +chown $mythwebuser:$mythwebgroup $myfolder""/DVD # Set folder permissions so the www-group can access them -chown -R mythtv:mythtv $myfolder"" +chown -R $mythtvuser:$mythtvgroup $myfolder"" chmod -R a+w $myfolder""/ -chown -R mythtv:www-data $myfolder""/images -chown -R mythtv:www-data $myfolder""/images/backgrounds/thumbnails -chown -R mythtv:www-data $myfolder""/music +chown -R $mythtvuser:$mythwebgroup $myfolder""/images +chown -R $mythtvuser:$mythwebgroup $myfolder""/images/backgrounds/thumbnails +chown -R $mythtvuser:$mythwebgroup $myfolder""/music chmod a+x $myfolder""/*.sh chmod a+x $myfolder""/scripts/*.sh chmod a+x $myfolder""/scripts/*.pl Index: mythtvburn.sh =================================================================== RCS file: /cvsroot/mythburn/mythburn/mythtvburn.sh,v retrieving revision 1.8 diff -u -B -b -r1.8 mythtvburn.sh --- mythtvburn.sh 3 Mar 2005 17:44:52 -0000 1.8 +++ mythtvburn.sh 19 Mar 2005 13:35:12 -0000 @@ -24,18 +24,11 @@ #set #exit -#Location of this script -myfolder=/myth/mythburn/mythburn - -#Location of mythtv recordings (tv folder on Knoppmyth) -mythtvlocation=/myth/tv +source /tmp/mythburn/config.sh # location of config file #Location of helper scripts scripts=$myfolder""/scripts -#Location of mythtvosd program -mythtvosd=/usr/bin/mythtvosd - # Now the actual scripts begin.... titlesperpage=4 smallfont=/usr/share/mythtv/FreeSans.ttf @@ -207,6 +200,7 @@ # Test all files exist before we begin and work out size of DVD for file in ${filenames[*]}; do +file=`echo $file | sed -e 's!.*/!!'` # cut the file location in mythtv 0.17 Gentoo if [ ! -e "$mythtvlocation""/$file" ]; then echo "File $file does not exist!" @@ -268,6 +262,7 @@ do checkstopflag $myfolder datestamp + file=`echo $file | sed -e 's!.*/!!'` # cut the file location in mythtv 0.17 Gentoo echo $file # Check if we're cutting commercials @@ -292,10 +287,10 @@ checkreturnvalue fi #$scripts""/apply_cutlist.sh $myfolder $myfolder""/temp/cutlist.txt $myfolder""/temp/$file - mchannel=$( echo $file | cut -c1-4) - mstarttime=$( echo $file | cut -c6-19) + mchannel=$( echo $file | cut --delimiter="_" -f 1 ) + mstarttime=$( echo $file | cut --delimiter="_" -f 2 ) sqlstatement2=" from recordedmarkup where recordedmarkup.chanid=$mchannel and recordedmarkup.starttime=$mstarttime and recordedmarkup.type=6 order by recordedmarkup.mark desc limit 1;" - mysql -uroot mythconverg -s -B --exec "select IFNULL(recordedmarkup.mark,'') $sqlstatement2" > $myfolder/temp/lastgop.txt + mysql -u$mysqluser -p$mysqlpass mythconverg -s -B --exec "select IFNULL(recordedmarkup.mark,'') $sqlstatement2" > $myfolder/temp/lastgop.txt checkreturnvalue LASTGOP=`cat $myfolder/temp/lastgop.txt` CUTLIST=`cat $myfolder/temp/cutlist-inverse.txt` @@ -320,12 +315,13 @@ for file in ${filenames[*]}; do + file=`echo $file | sed -e 's!.*/!!'` # cut the file location in mythtv 0.17 Gentoo checkstopflag $myfolder datestamp if [ ! -e "$myfolder""/temp/$file"".tcindex" ]; then - /usr/local/bin/tcdemux -i $myfolder""/temp/$file -W > $myfolder""/temp/$file.tcindex + $tcdemux -i $myfolder""/temp/$file -W > $myfolder""/temp/$file.tcindex checkreturnvalue fi done @@ -442,6 +438,7 @@ for file in ${filenames[*]}; do + file=`echo $file | sed -e 's!.*/!!'` # cut the file location in mythtv 0.17 Gentoo checkstopflag $myfolder @@ -524,9 +521,9 @@ rm -dfr $myfolder""/temp/$page""_$index"" mkdir $myfolder""/temp/$page""_$index"" -/usr/local/bin/transcode -q 0 -i $myfolder""/temp/$file"" -x auto,null -y jpg,null \ - -o $myfolder""/temp/$page""_$index""/V -Z 140x105 -k \ - -z --progress_off \ +$transcode $transcodeoptions -q 0 -i $myfolder""/temp/$file"" -x auto,null -y jpg,null \ + -o $myfolder""/temp/$page""_$index""/V -Z 140x105 \ + --progress_off \ --nav_seek $myfolder""/temp/$file"".tcindex \ -c 2000-$((2000 + maxanimframes)) checkreturnvalue @@ -597,6 +594,7 @@ index=1 for file in ${filenames[*]}; do + file=`echo $file | sed -e 's!.*/!!'` # cut the file location in mythtv 0.17 Gentoo echo "" >> $myxml echo "
" >> $myxml
 	echo "> $myxml
@@ -619,6 +617,7 @@
 #Convert menu PNGs to JPGs
 for file in $myfolder""/temp/output*.png
 do
+#	file=`echo $file | sed -e 's!.*/!!'` # cut the file location in mythtv 0.17 Gentoo
 	convert -quality 100 $file $file"".jpg
 	checkreturnvalue
 	rm $file
@@ -820,6 +819,7 @@
 
 for file in ${filenames[*]};
 do
+	file=`echo $file | sed -e 's!.*/!!'` # cut the file location in mythtv 0.17 Gentoo
 	rm -f $myfolder""/temp/$file
 	rm -f $myfolder""/temp/$file"".tcindex
 done
Index: images/backgrounds/plasma-fractal.png
===================================================================
RCS file: /cvsroot/mythburn/mythburn/images/backgrounds/plasma-fractal.png,v
retrieving revision 1.7
diff -u -B -b -r1.7 plasma-fractal.png
Binary files /tmp/cvs0wPPmk and plasma-fractal.png differ
Index: images/backgrounds/plasma-green-yellow.png
===================================================================
RCS file: /cvsroot/mythburn/mythburn/images/backgrounds/plasma-green-yellow.png,v
retrieving revision 1.7
diff -u -B -b -r1.7 plasma-green-yellow.png
Binary files /tmp/cvs8OPC8H and plasma-green-yellow.png differ
Index: images/backgrounds/thumbnails/gradient-dodgerblue.png
===================================================================
RCS file: /cvsroot/mythburn/mythburn/images/backgrounds/thumbnails/gradient-dodgerblue.png,v
retrieving revision 1.1.1.1
diff -u -B -b -r1.1.1.1 gradient-dodgerblue.png
Binary files /tmp/cvs0i8m25 and gradient-dodgerblue.png differ
Index: images/backgrounds/thumbnails/plasma-fractal.png
===================================================================
RCS file: /cvsroot/mythburn/mythburn/images/backgrounds/thumbnails/plasma-fractal.png,v
retrieving revision 1.7
diff -u -B -b -r1.7 plasma-fractal.png
Binary files /tmp/cvsySW69t and plasma-fractal.png differ
Index: images/backgrounds/thumbnails/plasma-green-yellow.png
===================================================================
RCS file: /cvsroot/mythburn/mythburn/images/backgrounds/thumbnails/plasma-green-yellow.png,v
retrieving revision 1.7
diff -u -B -b -r1.7 plasma-green-yellow.png
Binary files /tmp/cvsAcpVmS and plasma-green-yellow.png differ
Index: images/backgrounds/thumbnails/plasma-tomato.png
===================================================================
RCS file: /cvsroot/mythburn/mythburn/images/backgrounds/thumbnails/plasma-tomato.png,v
retrieving revision 1.7
diff -u -B -b -r1.7 plasma-tomato.png
Binary files /tmp/cvssi4xAg and plasma-tomato.png differ
Index: mythwebburn/mythtvburnconfig.xml
===================================================================
RCS file: /cvsroot/mythburn/mythburn/mythwebburn/mythtvburnconfig.xml,v
retrieving revision 1.8
diff -u -B -b -r1.8 mythtvburnconfig.xml
--- mythwebburn/mythtvburnconfig.xml	24 Feb 2005 18:57:17 -0000	1.8
+++ mythwebburn/mythtvburnconfig.xml	19 Mar 2005 13:39:43 -0000
@@ -1 +1 @@
-sea_scene.pngpalfunky2.mp2barbwire.pngyesnonono
\ No newline at end of file
+plasma-green-yellow.pngpalfunky1.mp2point_circle.pngnononoyes
\ No newline at end of file
Index: mythwebburn/mythtvburndvd.php
===================================================================
RCS file: /cvsroot/mythburn/mythburn/mythwebburn/mythtvburndvd.php,v
retrieving revision 1.2
diff -u -B -b -r1.2 mythtvburndvd.php
--- mythwebburn/mythtvburndvd.php	3 Oct 2004 18:27:08 -0000	1.2
+++ mythwebburn/mythtvburndvd.php	19 Mar 2005 13:39:43 -0000
@@ -3,7 +3,7 @@
     view and select programmes to burn to a standalone dvd.
 \***                                                                        ***/
 
-$mythburnfolder='/myth/mythburn/mythburn';
+    require_once "config.php";
 
 // Initialize the script, database, etc.
     require_once "includes/init.php";
Index: mythwebburn/mythtvburndvd_confirm.php
===================================================================
RCS file: /cvsroot/mythburn/mythburn/mythwebburn/mythtvburndvd_confirm.php,v
retrieving revision 1.4
diff -u -B -b -r1.4 mythtvburndvd_confirm.php
--- mythwebburn/mythtvburndvd_confirm.php	17 Feb 2005 21:21:16 -0000	1.4
+++ mythwebburn/mythtvburndvd_confirm.php	19 Mar 2005 13:39:43 -0000
@@ -3,6 +3,8 @@
     view and select programmes to burn to a standalone dvd.
 \***                                                                        ***/
 
+    require_once "config.php";
+
 // Initialize the script, database, etc.
     require_once "includes/init.php";
     require_once "includes/sorting.php";
@@ -11,8 +13,6 @@
     //header('Location: ./mythtvburndvd_confirm.php');
     //exit;
 
-$mythrecordings='/myth/tv';
-
 $file = "mythtvburnconfig.xml";
 $xml_parser = xml_parser_create();
 
Index: mythwebburn/mythtvburndvd_createdvd.php
===================================================================
RCS file: /cvsroot/mythburn/mythburn/mythwebburn/mythtvburndvd_createdvd.php,v
retrieving revision 1.6
diff -u -B -b -r1.6 mythtvburndvd_createdvd.php
--- mythwebburn/mythtvburndvd_createdvd.php	24 Feb 2005 18:57:17 -0000	1.6
+++ mythwebburn/mythtvburndvd_createdvd.php	19 Mar 2005 13:39:44 -0000
@@ -4,13 +4,12 @@
   
 \***                                                                        ***/
 
+    require_once "config.php";
+
 // Initialize the script, database, etc.
     require_once "includes/init.php";
     require_once "includes/sorting.php";
 
-$mythburnfolder='/myth/mythburn/mythburn';
-
-
 if (isset($_GET['cancel'])) {
   if ($_GET['cancel'] = "Y") {
 
@@ -113,7 +112,8 @@
 	}
 
         foreach ( $_GET['burnfile'] as $burnfile) {
-          $cmdline = $cmdline.escapeshellarg( str_replace('/','', $burnfile) )." ";
+          // Bruno adele bug ? $cmdline = $cmdline.escapeshellarg( str_replace('/','', $burnfile) )." ";
+          $cmdline = $cmdline.escapeshellarg( $burnfile )." ";
 	  $cmdline = $cmdline.escapeshellarg(($cutfiles[$burnfile]?'cut':'nocut'))." ";
         } 
 
Index: scripts/extractthumbnail.sh
===================================================================
RCS file: /cvsroot/mythburn/mythburn/scripts/extractthumbnail.sh,v
retrieving revision 1.3
diff -u -B -b -r1.3 extractthumbnail.sh
--- scripts/extractthumbnail.sh	24 Feb 2005 00:24:29 -0000	1.3
+++ scripts/extractthumbnail.sh	19 Mar 2005 13:39:44 -0000
@@ -4,6 +4,8 @@
 # 1st August 2004
 #Generate thumbnail image
 
+source /tmp/mythburn/config.sh # location of config file
+
 myfolder=$1
 
 cutlist=`cat $4`
@@ -12,8 +14,6 @@
 
 imagesize=$5
 
-transcode=`which transcode`
-
 function checkreturnvalue {
 retval=$?
 echo Return value is $retval
@@ -36,8 +36,8 @@
 echo "Extracting thumbnail image from time frame $cut"
 
 #	echo Running $transcode -q 0 -i "$2" -x auto,null -y jpg,null -o $3 -Z $imagesize -k -z --progress_off --nav_seek $2"".tcindex -c $cut
-
-	$transcode -q 0 -i "$2" -x auto,null -y jpg,null -o $3 -Z $imagesize -k -z --progress_off --nav_seek $2"".tcindex -c $cut
+	$transcode $transcodeoptions -q 0 -i "$2" -x auto,null -y jpg,null -o $3 -Z $imagesize --progress_off --nav_seek $2"".tcindex -c $cut
+	echo "############################after extract"
 
 #	checkreturnvalue
 
Index: scripts/getmyth.sh
===================================================================
RCS file: /cvsroot/mythburn/mythburn/scripts/getmyth.sh,v
retrieving revision 1.4
diff -u -B -b -r1.4 getmyth.sh
--- scripts/getmyth.sh	23 Feb 2005 19:41:19 -0000	1.4
+++ scripts/getmyth.sh	19 Mar 2005 13:39:44 -0000
@@ -6,6 +6,7 @@
 # writes various text files as output....
 # I'm sure this could be improved....
 
+source /tmp/mythburn/config.sh # location of config file
 
 if [ $# -ne 3 ]
 then
@@ -63,16 +63,16 @@
 
 echo $mnicestarttime >  $myfolder/""temp/date.txt
 
-mysql -uroot mythconverg -s -B --exec "select IFNULL(recorded.title,''),' ',IFNULL(recorded.subtitle,'') $sqlstatement" > $myfolder/temp/title1.txt
+mysql -u$mysqluser -p$mysqlpass mythconverg -s -B --exec "select IFNULL(recorded.title,''),' ',IFNULL(recorded.subtitle,'') $sqlstatement" > $myfolder/temp/title1.txt
 checkreturnvalue
-mysql -uroot mythconverg -s -B --exec "select IFNULL(recorded.description,'') $sqlstatement" > $myfolder/temp/description1.txt
+mysql -u$mysqluser -p$mysqlpass mythconverg -s -B --exec "select IFNULL(recorded.description,'') $sqlstatement" > $myfolder/temp/description1.txt
 checkreturnvalue
-mysql -uroot mythconverg -s -B --exec "select IFNULL(recorded.cutlist,'') $sqlstatement" > $myfolder/temp/cutlist.txt
+mysql -u$mysqluser -p$mysqlpass mythconverg -s -B --exec "select IFNULL(recorded.cutlist,'') $sqlstatement" > $myfolder/temp/cutlist.txt
 checkreturnvalue
-mysql -uroot mythconverg -s -B --exec "select IFNULL(recorded.category,'') $sqlstatement" > $myfolder/temp/category.txt
+mysql -u$mysqluser -p$mysqlpass mythconverg -s -B --exec "select IFNULL(recorded.category,'') $sqlstatement" > $myfolder/temp/category.txt
 checkreturnvalue
 #not yet required
 #mysql -uroot mythconverg -s -B --exec "select mark,offset,type FROM recordedmarkup where chanid=$mchannel and starttime=$mstarttime" > $myfolder/temp/recordedmarkup.txt
 
 #cat /myth/mythtvburn/temp/title1.txt | cut -c1-35 > $myfolder/temp/title.txt
@@ -63,16 +63,16 @@
 checkreturnvalue
 #not yet required
-#mysql -uroot mythconverg -s -B --exec "select mark,offset,type FROM recordedmarkup where chanid=$mchannel and starttime=$mstarttime" > $myfolder/temp/recordedmarkup.txt
+#mysql -u$mysqluser mythconverg -s -B --exec "select mark,offset,type FROM recordedmarkup where chanid=$mchannel and starttime=$mstarttime" > $myfolder/temp/recordedmarkup.txt
 
 #cat /myth/mythtvburn/temp/title1.txt | cut -c1-35 > $myfolder/temp/title.txt